@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2013 The PHP Group                                |
+   | Copyright (c) 1997-2014 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -43,17 +43,20 @@ static zend_always_inline evutil_socket_t zval_to_signum(zval **ppzfd)
 static void timer_cb(evutil_socket_t fd, short what, void *arg)
 {
 	php_event_t *e = (php_event_t *) arg;
+	zend_fcall_info     *pfci;
+	zval                *arg_data;
+	zval               **args[1];
+	zval                *retval_ptr = NULL;
+	PHP_EVENT_TSRM_DECL
 
 	PHP_EVENT_ASSERT(e);
 	PHP_EVENT_ASSERT(what & EV_TIMEOUT);
 	PHP_EVENT_ASSERT(e->fci && e->fcc);
 
-	zend_fcall_info     *pfci       = e->fci;
-	zval                *arg_data   = e->data;
-	zval               **args[1];
-	zval                *retval_ptr;
+	pfci     = e->fci;
+	arg_data = e->data;
 
-	TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
+	PHP_EVENT_TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
 
 	if (ZEND_FCI_INITIALIZED(*pfci)) {
 		/* Setup callback arg */
@@ -87,18 +90,21 @@ static void timer_cb(evutil_socket_t fd, short what, void *arg)
 static void event_cb(evutil_socket_t fd, short what, void *arg)
 {
 	php_event_t *e = (php_event_t *) arg;
+	zend_fcall_info     *pfci;
+	zval                *arg_data;
+	zval                *arg_fd;
+	zval                *arg_what;
+	zval               **args[3];
+	zval                *retval_ptr = NULL;
+	PHP_EVENT_TSRM_DECL
 
 	PHP_EVENT_ASSERT(e);
 	PHP_EVENT_ASSERT(e->fci && e->fcc);
 
-	zend_fcall_info     *pfci       = e->fci;
-	zval                *arg_data   = e->data;
-	zval                *arg_fd;
-	zval                *arg_what;
-	zval               **args[3];
-	zval                *retval_ptr;
+	pfci       = e->fci;
+	arg_data   = e->data;
 
-	TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
+	PHP_EVENT_TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
 
 	if (ZEND_FCI_INITIALIZED(*pfci)) {
 		/* Setup callback arguments */
@@ -149,18 +155,21 @@ static void event_cb(evutil_socket_t fd, short what, void *arg)
 static void signal_cb(evutil_socket_t signum, short what, void *arg)
 {
 	php_event_t *e = (php_event_t *) arg;
+	zend_fcall_info     *pfci;
+	zval                *arg_data;
+	zval                *arg_signum;
+	zval               **args[2];
+	zval                *retval_ptr = NULL;
+	PHP_EVENT_TSRM_DECL
 
 	PHP_EVENT_ASSERT(e);
 	PHP_EVENT_ASSERT(what & EV_SIGNAL);
 	PHP_EVENT_ASSERT(e->fci && e->fcc);
 
-	zend_fcall_info     *pfci       = e->fci;
-	zval                *arg_data   = e->data;
-	zval                *arg_signum;
-	zval               **args[2];
-	zval                *retval_ptr;
+	pfci     = e->fci;
+	arg_data = e->data;
 
-	TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
+	PHP_EVENT_TSRMLS_FETCH_FROM_CTX(e->thread_ctx);
 
 	if (ZEND_FCI_INITIALIZED(*pfci)) {
 		/* Setup callback args */
@@ -219,6 +228,8 @@ PHP_METHOD(Event, __construct)
 		return;
 	}
 
+	PHP_EVENT_REQUIRE_BASE_BY_REF(zbase);
+
 	if (what & ~(EV_TIMEOUT | EV_READ | EV_WRITE | EV_SIGNAL | EV_PERSIST | EV_ET)) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid mask");
 		ZVAL_NULL(zself);
@@ -308,7 +319,7 @@ PHP_METHOD(Event, set)
 	zval                   *zevent  = getThis();
 	php_event_t            *e;
 	zval                  **ppzfd   = NULL;
-	evutil_socket_t         fd;
+	evutil_socket_t         fd = -1;
 	long                    what    = -1;
 	zend_fcall_info         fci     = empty_fcall_info;
 	zend_fcall_info_cache   fcc     = empty_fcall_info_cache;
@@ -320,6 +331,8 @@ PHP_METHOD(Event, set)
 		return;
 	}
 
+	PHP_EVENT_REQUIRE_BASE_BY_REF(zbase);
+
 	if (what != -1) {
 		if (what & ~(EV_TIMEOUT | EV_READ | EV_WRITE | EV_SIGNAL | EV_PERSIST | EV_ET)) {
 			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid events mask");
@@ -556,6 +569,8 @@ PHP_METHOD(Event, timer)
 		return;
 	}
 
+	PHP_EVENT_REQUIRE_BASE_BY_REF(zbase);
+
 	PHP_EVENT_FETCH_BASE(b, zbase);
 
 	PHP_EVENT_INIT_CLASS_OBJECT(return_value, php_event_ce);
@@ -600,6 +615,8 @@ PHP_METHOD(Event, setTimer)
 		return;
 	}
 
+	PHP_EVENT_REQUIRE_BASE_BY_REF(zbase);
+
 	PHP_EVENT_FETCH_EVENT(e, zevent);
 
 	if (evtimer_pending(e->event, NULL)) {
@@ -647,13 +664,15 @@ PHP_METHOD(Event, signal)
 	zval                  *arg    = NULL;
 	php_event_t           *e;
 	struct event          *event;
-	
+
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "Olf|z",
 				&zbase, php_event_base_ce, &signum, &fci, &fcc, &arg) == FAILURE) {
 		return;
 	}
-	
+
+	PHP_EVENT_REQUIRE_BASE_BY_REF(zbase);
+
 	if (signum < 0 || signum >= NSIG) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid signal passed");
 		RETURN_FALSE;
